@@ -16,12 +16,16 @@ def resolve_dbutils() -> DBUtils:
 
 
 def get_workspace_api() -> WorkspaceApi:
-    api_client = ApiClient(host=get_host(), token=get_token())
+    dbutils = resolve_dbutils()
+
+    api_client = ApiClient(host=get_host(), token=get_token(dbutils))
     return WorkspaceApi(api_client)
 
 
 def get_repos_api() -> ReposApi:
-    api_client = ApiClient(host=get_host(), token=get_token())
+    dbutils = resolve_dbutils()
+
+    api_client = ApiClient(host=get_host(), token=get_token(dbutils))
     return ReposApi(api_client)
 
 
@@ -30,11 +34,5 @@ def get_host() -> str:
     return f"https://{spark.conf.get('spark.databricks.workspaceUrl')}"
 
 
-def get_token() -> str:
-    dbutils = resolve_dbutils()
+def get_token(dbutils: DBUtils) -> str:
     return dbutils.notebook.entry_point.getDbutils().notebook().getContext().apiToken().get()
-
-
-def get_username() -> str:
-    dbutils = resolve_dbutils()
-    return dbutils.notebook.entry_point.getDbutils().notebook().getContext().userName().get()
\ No newline at end of file
